@@ -40,6 +40,7 @@ from errno import ECONNREFUSED
 import random
 import gzip
 from io import StringIO
+from six import ensure_binary
 try:
     from urllib2 import urlparse
     urlparse = urlparse.urlparse
@@ -224,8 +225,7 @@ class TCPsocket(PlugIn):
         #print('type:', type(raw_data))
         if type(raw_data)==type(''): raw_data = raw_data
         elif type(raw_data)!=type(''): raw_data = ustr(raw_data)
-        if sys.version_info.major >= 3:
-            raw_data = raw_data.encode('utf-8')
+        raw_data=ensure_binary(raw_data,'utf-8')
         try:
             sent = 0
             while not sent:
@@ -384,7 +384,11 @@ class TLS(PlugIn):
         """ Immidiatedly switch socket to TLS mode. Used internally."""
         """ Here we should switch pending_data to hint mode."""
         tcpsock=self._owner.Connection
-        tcpsock._sslObj    = ssl.wrap_socket(tcpsock._sock, None, None)
+        context=ssl.SSLContext(ssl.PROTOCOL_TLS_CLIENT)
+        context.check_hostname = False
+        context.verify_mode = ssl.CERT_NONE
+
+        tcpsock._sslObj    = context.wrap_socket(tcpsock._sock)
         tcpsock._sslIssuer = tcpsock._sslObj.getpeercert().get('issuer')
         tcpsock._sslServer = tcpsock._sslObj.getpeercert().get('server')
         tcpsock._recv = tcpsock._sslObj.read
@@ -694,7 +698,7 @@ class Bosh(PlugIn):
         default['Content-Length'] = len(bosh_data)
         if self.GZIP:
             default['Accept-Encoding'] = 'gzip, deflate'
-        headers = dict(default, **headers) 
+        headers = dict(default, **headers)
         conn = self.Connection()
         if self.PIPELINE:
             conn._HTTPConnection__state = _CS_IDLE
